USER_INFORMATION = {
    "object": "user",
    "url": "https://api.wanikani.com/v2/user",
    "data_updated_at": "2020-05-01T05:20:41.769053Z",
    "data": {
        "id": "7a18daeb-4067-4e77-b0ea-230c7c347ea8",
        "username": "Tadgh11",
        "level": 12,
        "profile_url": "https://www.wanikani.com/users/Tadgh11",
        "started_at": "2013-07-09T12:02:54.952786Z",
        "subscription": {
            "active": True,
            "type": "lifetime",
            "max_level_granted": 60,
            "period_ends_at": None
        },
        "current_vacation_started_at": None,
        "preferences": {
            "lessons_batch_size": 5,
            "lessons_autoplay_audio": True,
            "reviews_autoplay_audio": False,
            "lessons_presentation_order": "ascending_level_then_subject",
            "reviews_display_srs_indicator": True
        }
    }
}

SUBJECT = {
    "id": 2467,
    "object": "vocabulary",
    "url": "https://api.wanikani.com/v2/subjects/2467",
    "data_updated_at": "2018-05-21T21:52:43.041390Z",
    "data": {
        "created_at": "2012-02-28T08:04:47.000000Z",
        "level": 1,
        "slug": "一",
        "hidden_at": None,
        "document_url": "https://www.wanikani.com/vocabulary/%E4%B8%80",
        "characters": "一",
        "meanings": [{"meaning": "One", "primary": True, "accepted_answer": True}],
        "readings": [{"primary": True, "reading": "いち", "accepted_answer": True}],
        "parts_of_speech": ["numeral"],
        "component_subject_ids": [440],
        "auxiliary_meanings": [],
    },
}

SINGLE_SUBJECT = {
    "id": 1,
    "object": "radical",
    "url": "https://api.wanikani.com/v2/subjects/1",
    "data_updated_at": "2022-07-24T01:22:18.573676Z",
    "data": {
        "created_at": "2012-02-27T18:08:16.000000Z",
        "level": 1,
        "slug": "ground",
        "hidden_at": None,
        "document_url": "https://www.wanikani.com/radicals/ground",
        "characters": "一",
        "character_images": [
            {
                "url": "https://files.wanikani.com/a7w32gazaor51ii0fbtxzk0wpmpc",
                "metadata": {
                    "inline_styles": False
                },
                "content_type": "image/svg+xml"
            },
            {
                "url": "https://files.wanikani.com/fxufa23ht9uh0tkedo1zx5jemaio",
                "metadata": {
                    "inline_styles": True
                },
                "content_type": "image/svg+xml"
            },
            {
                "url": "https://files.wanikani.com/4lxmimfbwuvl07s11dq0f9til0mb",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "1024x1024",
                    "style_name": "original"
                },
                "content_type": "image/png"
            },
            {
                "url": "https://files.wanikani.com/3n3dlzyjjgou47qb4h4uewghcfcx",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "1024x1024",
                    "style_name": "1024px"
                },
                "content_type": "image/png"
            },
            {
                "url": "https://files.wanikani.com/9d5fax4vrjp28vms1jb11ouu37vi",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "512x512",
                    "style_name": "512px"
                },
                "content_type": "image/png"
            },
            {
                "url": "https://files.wanikani.com/gfwzjl41i5v5oiwrsjz5zz957nww",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "256x256",
                    "style_name": "256px"
                },
                "content_type": "image/png"
            },
            {
                "url": "https://files.wanikani.com/m79ver1yfujpkcfa0bo5tcueuxk3",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "128x128",
                    "style_name": "128px"
                },
                "content_type": "image/png"
            },
            {
                "url": "https://files.wanikani.com/gcqkjhbw9aguieat8yrqxz09qszn",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "64x64",
                    "style_name": "64px"
                },
                "content_type": "image/png"
            },
            {
                "url": "https://files.wanikani.com/7czfgjlgsjxx8sndvfkezts6ugj1",
                "metadata": {
                    "color": "#000000",
                    "dimensions": "32x32",
                    "style_name": "32px"
                },
                "content_type": "image/png"
            }
        ],
        "meanings": [
            {
                "meaning": "Ground",
                "primary": True,
                "accepted_answer": True
            }
        ],
        "auxiliary_meanings": [],
        "amalgamation_subject_ids": [
            440,
            449,
            450,
            451,
            468,
            488,
            531,
            533,
            568,
            590,
            609,
            633,
            635,
            709,
            710,
            724,
            783,
            808,
            885,
            913,
            932,
            965,
            971,
            1000,
            1020,
            1085,
            1113,
            1119,
            1126,
            1137,
            1178,
            1198,
            1241,
            1249,
            1326,
            1340,
            1367,
            1372,
            1376,
            1379,
            1428,
            1431,
            1463,
            1491,
            1506,
            1521,
            1547,
            1559,
            1591,
            1655,
            1769,
            1851,
            1852,
            1855,
            1868,
            1869,
            1888,
            1970,
            2091,
            2104,
            2128,
            2138,
            2148,
            2171,
            2172,
            2182,
            2212,
            2277,
            2334,
            2375,
            2419,
            2437
        ],
        "meaning_mnemonic": "This radical consists of a single, horizontal stroke. What's the biggest, single, horizontal stroke? That's the <radical>ground</radical>. Look at the ground, look at this radical, now look at the ground again. Kind of the same, right?",
        "lesson_position": 0,
        "spaced_repetition_system_id": 2
    }
}

EMPTY_SUBJECTS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/subjects?ids=1%2C2%2C3&slugs=abc%2C123&types=vocabulary",
    "pages": {"per_page": 1000, "next_url": None, "previous_url": None},
    "total_count": 0,
    "data_updated_at": None,
    "data": [],
}

SUBJECTS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/subjects",
    "pages": {"per_page": 1000, "next_url": None, "previous_url": None},
    "total_count": 3,
    "data_updated_at": "2018-07-05T22:22:07.129381Z",
    "data": [
        {
            "id": 1,
            "object": "radical",
            "url": "https://api.wanikani.com/v2/subjects/1",
            "data_updated_at": "2022-07-24T01:22:18.573676Z",
            "data": {
                "created_at": "2012-02-27T18:08:16.000000Z",
                "level": 1,
                "slug": "ground",
                "hidden_at": None,
                "document_url": "https://www.wanikani.com/radicals/ground",
                "characters": "一",
                "character_images": [
                    {
                        "url": "https://files.wanikani.com/a7w32gazaor51ii0fbtxzk0wpmpc",
                        "metadata": {
                            "inline_styles": False
                        },
                        "content_type": "image/svg+xml"
                    },
                    {
                        "url": "https://files.wanikani.com/fxufa23ht9uh0tkedo1zx5jemaio",
                        "metadata": {
                            "inline_styles": True
                        },
                        "content_type": "image/svg+xml"
                    },
                    {
                        "url": "https://files.wanikani.com/4lxmimfbwuvl07s11dq0f9til0mb",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "1024x1024",
                            "style_name": "original"
                        },
                        "content_type": "image/png"
                    },
                    {
                        "url": "https://files.wanikani.com/3n3dlzyjjgou47qb4h4uewghcfcx",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "1024x1024",
                            "style_name": "1024px"
                        },
                        "content_type": "image/png"
                    },
                    {
                        "url": "https://files.wanikani.com/9d5fax4vrjp28vms1jb11ouu37vi",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "512x512",
                            "style_name": "512px"
                        },
                        "content_type": "image/png"
                    },
                    {
                        "url": "https://files.wanikani.com/gfwzjl41i5v5oiwrsjz5zz957nww",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "256x256",
                            "style_name": "256px"
                        },
                        "content_type": "image/png"
                    },
                    {
                        "url": "https://files.wanikani.com/m79ver1yfujpkcfa0bo5tcueuxk3",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "128x128",
                            "style_name": "128px"
                        },
                        "content_type": "image/png"
                    },
                    {
                        "url": "https://files.wanikani.com/gcqkjhbw9aguieat8yrqxz09qszn",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "64x64",
                            "style_name": "64px"
                        },
                        "content_type": "image/png"
                    },
                    {
                        "url": "https://files.wanikani.com/7czfgjlgsjxx8sndvfkezts6ugj1",
                        "metadata": {
                            "color": "#000000",
                            "dimensions": "32x32",
                            "style_name": "32px"
                        },
                        "content_type": "image/png"
                    }
                ],
                "meanings": [
                    {
                        "meaning": "Ground",
                        "primary": True,
                        "accepted_answer": True
                    }
                ],
                "auxiliary_meanings": [],
                "amalgamation_subject_ids": [
                    440,
                    449,
                    450,
                    451,
                    468,
                    488,
                    531,
                    533,
                    568,
                    590,
                    609,
                    633,
                    635,
                    709,
                    710,
                    724,
                    783,
                    808,
                    885,
                    913,
                    932,
                    965,
                    971,
                    1000,
                    1020,
                    1085,
                    1113,
                    1119,
                    1126,
                    1137,
                    1178,
                    1198,
                    1241,
                    1249,
                    1326,
                    1340,
                    1367,
                    1372,
                    1376,
                    1379,
                    1428,
                    1431,
                    1463,
                    1491,
                    1506,
                    1521,
                    1547,
                    1559,
                    1591,
                    1655,
                    1769,
                    1851,
                    1852,
                    1855,
                    1868,
                    1869,
                    1888,
                    1970,
                    2091,
                    2104,
                    2128,
                    2138,
                    2148,
                    2171,
                    2172,
                    2182,
                    2212,
                    2277,
                    2334,
                    2375,
                    2419,
                    2437
                ],
                "meaning_mnemonic": "This radical consists of a single, horizontal stroke. What's the biggest, single, horizontal stroke? That's the <radical>ground</radical>. Look at the ground, look at this radical, now look at the ground again. Kind of the same, right?",
                "lesson_position": 0,
                "spaced_repetition_system_id": 2
            }
        },
        {
            "id": 2,
            "object": "kanji",
            "url": "https://api.wanikani.com/v2/subjects/534",
            "data_updated_at": "2022-05-30T19:39:55.744373Z",
            "data": {
                "created_at": "2012-03-02T02:11:55.000000Z",
                "level": 4,
                "slug": "央",
                "hidden_at": None,
                "document_url": "https://www.wanikani.com/kanji/%E5%A4%AE",
                "characters": "央",
                "meanings": [
                    {
                        "meaning": "Center",
                        "primary": True,
                        "accepted_answer": True
                    },
                    {
                        "meaning": "Centre",
                        "primary": False,
                        "accepted_answer": True
                    }
                ],
                "auxiliary_meanings": [],
                "readings": [
                    {
                        "type": "onyomi",
                        "primary": True,
                        "reading": "おう",
                        "accepted_answer": True
                    }
                ],
                "component_subject_ids": [
                    18,
                    29
                ],
                "amalgamation_subject_ids": [
                    2726
                ],
                "visually_similar_subject_ids": [],
                "meaning_mnemonic": "If someone has a <radical>big</radical> <radical>head</radical> you have to try to focus on the <kanji>center</kanji> of it when you talk to them.",
                "meaning_hint": "You don't want to get caught with your eyes wandering all over their big head. Stare right at the center of their face. Ah geez, their eyes are kinda far away from here. You can really only see their nose...",
                "reading_mnemonic": "This is the <kanji>center</kanji> of the <ja><reading>王</reading></ja>'s (<ja>おう</ja>) head so you have to be extra careful not to look anywhere else.",
                "reading_hint": "The <ja>王</ja> will definitely cut off your normal-sized head if he sees you looking all over his big head and not at the center.",
                "lesson_position": 0,
                "spaced_repetition_system_id": 1
            }
        },
        {
            "id": 3,
            "object": "vocabulary",
            "url": "https://api.wanikani.com/v2/subjects/2467",
            "data_updated_at": "2021-09-01T18:22:40.891504Z",
            "data": {
                "created_at": "2012-02-28T08:04:47.000000Z",
                "level": 1,
                "slug": "一",
                "hidden_at": None,
                "document_url": "https://www.wanikani.com/vocabulary/%E4%B8%80",
                "characters": "一",
                "meanings": [
                    {
                        "meaning": "One",
                        "primary": True,
                        "accepted_answer": True
                    }
                ],
                "auxiliary_meanings": [
                    {
                        "type": "whitelist",
                        "meaning": "1"
                    }
                ],
                "readings": [
                    {
                        "primary": True,
                        "reading": "いち",
                        "accepted_answer": True
                    }
                ],
                "parts_of_speech": [
                    "numeral"
                ],
                "component_subject_ids": [
                    440
                ],
                "meaning_mnemonic": "As is the case with most vocab words that consist of a single kanji, this vocab word has the same meaning as the kanji it parallels, which is <vocabulary>one</vocabulary>.",
                "reading_mnemonic": "When a vocab word is all alone and has no okurigana (hiragana attached to kanji) connected to it, it usually uses the kun'yomi reading. Numbers are an exception, however. When a number is all alone, with no kanji or okurigana, it is going to be the on'yomi reading, which you learned with the kanji.  Just remember this exception for alone numbers and you'll be able to read future number-related vocab to come.",
                "context_sentences": [
                    {
                        "en": "Let’s meet up once.",
                        "ja": "一ど、あいましょう。"
                    },
                    {
                        "en": "First place was an American.",
                        "ja": "一いはアメリカ人でした。"
                    },
                    {
                        "en": "I’m the weakest (person) in the world.",
                        "ja": "ぼくはせかいで一ばんよわい。"
                    }
                ],
                "pronunciation_audios": [
                    {
                        "url": "https://files.wanikani.com/aeevlg446own3mcs6rye6k4wfq37",
                        "metadata": {
                            "gender": "female",
                            "source_id": 21630,
                            "pronunciation": "いち",
                            "voice_actor_id": 1,
                            "voice_actor_name": "Kyoko",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/ogg"
                    },
                    {
                        "url": "https://files.wanikani.com/w6loj76y9t8ppripy1eindt5dg3y",
                        "metadata": {
                            "gender": "female",
                            "source_id": 21630,
                            "pronunciation": "いち",
                            "voice_actor_id": 1,
                            "voice_actor_name": "Kyoko",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/webm"
                    },
                    {
                        "url": "https://files.wanikani.com/j5dy9yyxpzsywaxifq1c7yc3ctal",
                        "metadata": {
                            "gender": "male",
                            "source_id": 2711,
                            "pronunciation": "いち",
                            "voice_actor_id": 2,
                            "voice_actor_name": "Kenichi",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/webm"
                    },
                    {
                        "url": "https://files.wanikani.com/tfdkyds03nhrbs6to3e0q4avbg1u",
                        "metadata": {
                            "gender": "male",
                            "source_id": 2711,
                            "pronunciation": "いち",
                            "voice_actor_id": 2,
                            "voice_actor_name": "Kenichi",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/webm"
                    },
                    {
                        "url": "https://files.wanikani.com/vtyum09bj9tf2gle7i4ip04iao6s",
                        "metadata": {
                            "gender": "female",
                            "source_id": 21630,
                            "pronunciation": "いち",
                            "voice_actor_id": 1,
                            "voice_actor_name": "Kyoko",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/webm"
                    },
                    {
                        "url": "https://files.wanikani.com/5g89i8489j2joklaqdoy89rzhlqf",
                        "metadata": {
                            "gender": "male",
                            "source_id": 2711,
                            "pronunciation": "いち",
                            "voice_actor_id": 2,
                            "voice_actor_name": "Kenichi",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/ogg"
                    },
                    {
                        "url": "https://files.wanikani.com/jkdnvm82i2kl6my5ts67idq2qdc6",
                        "metadata": {
                            "gender": "male",
                            "source_id": 2711,
                            "pronunciation": "いち",
                            "voice_actor_id": 2,
                            "voice_actor_name": "Kenichi",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/mpeg"
                    },
                    {
                        "url": "https://files.wanikani.com/dwikzn441ltuq4evi7bmt5g3v7q2",
                        "metadata": {
                            "gender": "female",
                            "source_id": 21630,
                            "pronunciation": "いち",
                            "voice_actor_id": 1,
                            "voice_actor_name": "Kyoko",
                            "voice_description": "Tokyo accent"
                        },
                        "content_type": "audio/mpeg"
                    }
                ],
                "lesson_position": 44,
                "spaced_repetition_system_id": 2
            }
        }
    ],
}

ASSIGNMENTS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/assignments",
    "pages": {
        "per_page": 500,
        "next_url": "https://api.wanikani.com/v2/assignments?page_after_id=62308815",
        "previous_url": None,
    },
    "total_count": 3,
    "data_updated_at": "2018-06-30T16:40:52.513654Z",
    "data": [
        {
            "id": 210688274,
            "object": "assignment",
            "url": "https://api.wanikani.com/v2/assignments/210688274",
            "data_updated_at": "2021-08-09T13:08:32.510479Z",
            "data": {
                "created_at": "2020-12-09T21:36:31.745922Z",
                "subject_id": 1,
                "subject_type": "vocabulary",
                "srs_stage": 8,
                "unlocked_at": "2020-12-09T21:36:31.739267Z",
                "started_at": "2020-12-09T23:24:56.021005Z",
                "passed_at": "2020-12-17T21:49:13.130832Z",
                "burned_at": None,
                "available_at": "2021-12-05T18:00:00.000000Z",
                "resurrected_at": None,
                "hidden": False
            }
        },
        {
            "id": 210688287,
            "object": "assignment",
            "url": "https://api.wanikani.com/v2/assignments/210688287",
            "data_updated_at": "2021-07-16T00:37:57.764169Z",
            "data": {
                "created_at": "2020-12-09T21:36:31.913653Z",
                "subject_id": 2,
                "subject_type": "vocabulary",
                "srs_stage": 8,
                "unlocked_at": "2020-12-09T21:36:31.905996Z",
                "started_at": "2020-12-09T23:26:34.608307Z",
                "passed_at": "2020-12-19T21:31:47.175944Z",
                "burned_at": None,
                "available_at": "2021-11-12T23:00:00.000000Z",
                "resurrected_at": None,
                "hidden": False
            }
        },
        {
            "id": 210688308,
            "object": "assignment",
            "url": "https://api.wanikani.com/v2/assignments/210688308",
            "data_updated_at": "2021-11-21T19:30:31.513789Z",
            "data": {
                "created_at": "2020-12-09T21:36:32.314040Z",
                "subject_id": 3,
                "subject_type": "vocabulary",
                "srs_stage": 9,
                "unlocked_at": "2020-12-09T21:36:32.301446Z",
                "started_at": "2020-12-09T23:27:17.833377Z",
                "passed_at": "2020-12-15T23:17:18.377500Z",
                "burned_at": "2021-11-21T19:30:31.465624Z",
                "available_at": None,
                "resurrected_at": None,
                "hidden": False
            }
        },
    ],
}

REVIEW_STATISTICS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/review_statistics",
    "pages": {
        "per_page": 500,
        "next_url": "https://api.wanikani.com/v2/review_statistics?page_after_id=62308745",
        "previous_url": None,
    },
    "total_count": 5,
    "data_updated_at": "2018-05-24T22:02:41.393482Z",
    "data": [
        {
            "id": 85899,
            "object": "review_statistic",
            "url": "https://api.wanikani.com/v2/review_statistics/85899",
            "data_updated_at": "2018-01-03T00:08:22.469272Z",
            "data": {
                "created_at": "2017-04-15T14:53:56.818837Z",
                "subject_id": 1,
                "subject_type": "vocabulary",
                "meaning_correct": 13,
                "meaning_incorrect": 2,
                "meaning_max_streak": 7,
                "meaning_current_streak": 7,
                "reading_correct": 13,
                "reading_incorrect": 0,
                "reading_max_streak": 13,
                "reading_current_streak": 13,
                "percentage_correct": 93,
                "hidden": False,
            },
        },
        {
            "id": 86555,
            "object": "review_statistic",
            "url": "https://api.wanikani.com/v2/review_statistics/86555",
            "data_updated_at": "2018-02-19T23:02:25.114612Z",
            "data": {
                "created_at": "2017-04-15T14:50:51.503084Z",
                "subject_id": 2,
                "subject_type": "vocabulary",
                "meaning_correct": 11,
                "meaning_incorrect": 0,
                "meaning_max_streak": 11,
                "meaning_current_streak": 11,
                "reading_correct": 11,
                "reading_incorrect": 1,
                "reading_max_streak": 7,
                "reading_current_streak": 7,
                "percentage_correct": 96,
                "hidden": False,
            },
        },
        {
            "id": 86606,
            "object": "review_statistic",
            "url": "https://api.wanikani.com/v2/review_statistics/86606",
            "data_updated_at": "2018-02-19T22:46:09.166397Z",
            "data": {
                "created_at": "2017-04-24T15:17:28.712677Z",
                "subject_id": 3,
                "subject_type": "vocabulary",
                "meaning_correct": 8,
                "meaning_incorrect": 0,
                "meaning_max_streak": 8,
                "meaning_current_streak": 8,
                "reading_correct": 8,
                "reading_incorrect": 0,
                "reading_max_streak": 8,
                "reading_current_streak": 8,
                "percentage_correct": 100,
                "hidden": False,
            },
        },
        {
            "id": 86625,
            "object": "review_statistic",
            "url": "https://api.wanikani.com/v2/review_statistics/86625",
            "data_updated_at": "2018-02-19T23:54:40.912486Z",
            "data": {
                "created_at": "2017-04-24T15:17:29.061457Z",
                "subject_id": 1,
                "subject_type": "radical",
                "meaning_correct": 8,
                "meaning_incorrect": 0,
                "meaning_max_streak": 8,
                "meaning_current_streak": 8,
                "reading_correct": 1,
                "reading_incorrect": 0,
                "reading_max_streak": 1,
                "reading_current_streak": 1,
                "percentage_correct": 100,
                "hidden": False,
            },
        },
        {
            "id": 86891,
            "object": "review_statistic",
            "url": "https://api.wanikani.com/v2/review_statistics/86891",
            "data_updated_at": "2018-05-24T21:35:18.556752Z",
            "data": {
                "created_at": "2017-04-24T15:17:38.685804Z",
                "subject_id": 3,
                "subject_type": "vocabulary",
                "meaning_correct": 12,
                "meaning_incorrect": 1,
                "meaning_max_streak": 11,
                "meaning_current_streak": 11,
                "reading_correct": 12,
                "reading_incorrect": 1,
                "reading_max_streak": 9,
                "reading_current_streak": 3,
                "percentage_correct": 92,
                "hidden": False,
            },
        },
    ],
}

STUDY_MATERIALS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/study_materials",
    "pages": {"per_page": 500, "next_url": None, "previous_url": None},
    "total_count": 3,
    "data_updated_at": "2018-02-20T21:23:31.246408Z",
    "data": [
        {
            "id": 1539170,
            "object": "study_material",
            "url": "https://api.wanikani.com/v2/study_materials/1539170",
            "data_updated_at": "2017-06-01T19:01:36.573350Z",
            "data": {
                "created_at": "2017-02-01T15:55:42.058583Z",
                "subject_id": 7518,
                "subject_type": "vocabulary",
                "meaning_note": None,
                "reading_note": None,
                "meaning_synonyms": ["young girl"],
                "hidden": False,
            },
        },
        {
            "id": 1661853,
            "object": "study_material",
            "url": "https://api.wanikani.com/v2/study_materials/1661853",
            "data_updated_at": "2017-06-07T00:23:41.431508Z",
            "data": {
                "created_at": "2017-04-08T14:02:50.758641Z",
                "subject_id": 2798,
                "subject_type": "vocabulary",
                "meaning_note": None,
                "reading_note": None,
                "meaning_synonyms": ["balls"],
                "hidden": False,
            },
        },
        {
            "id": 1678472,
            "object": "study_material",
            "url": "https://api.wanikani.com/v2/study_materials/1678472",
            "data_updated_at": "2017-06-12T15:22:15.753065Z",
            "data": {
                "created_at": "2017-02-23T14:51:21.526934Z",
                "subject_id": 3416,
                "subject_type": "vocabulary",
                "meaning_note": None,
                "reading_note": None,
                "meaning_synonyms": ["wool"],
                "hidden": False,
            },
        },
    ],
}

SUMMARY = {
    "object": "report",
    "url": "https://api.wanikani.com/v2/summary",
    "data_updated_at": "2018-07-02T07:00:00.000000Z",
    "data": {
        "lessons": [{"available_at": "2018-07-02T07:00:00.000000Z", "subject_ids": []}],
        "next_reviews_at": "2018-07-02T09:00:00.000000Z",
        "reviews": [
            {"available_at": "2018-07-02T07:00:00.000000Z", "subject_ids": [1, 2, 3]},
            {"available_at": "2018-07-02T08:00:00.000000Z", "subject_ids": [4, 5, 6]},
            {"available_at": "2018-07-02T09:00:00.000000Z", "subject_ids": [647]},
            {"available_at": "2018-07-02T10:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T11:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T12:00:00.000000Z", "subject_ids": []},
            {
                "available_at": "2018-07-02T13:00:00.000000Z",
                "subject_ids": [8800, 2944, 2943],
            },
            {"available_at": "2018-07-02T14:00:00.000000Z", "subject_ids": []},
            {
                "available_at": "2018-07-02T15:00:00.000000Z",
                "subject_ids": [
                    658,
                    8738,
                    3447,
                    6237,
                    3449,
                    3451,
                    7676,
                    7528,
                    7621,
                    7679,
                    2822,
                    3420,
                    657,
                    5717,
                    3436,
                    7677,
                    7678,
                    3452,
                    7529,
                    3450,
                    3438,
                    7568,
                    7675,
                    3437,
                    3422,
                    3448,
                    4877,
                    7734,
                    7735,
                    666,
                    646,
                    648,
                ],
            },
            {"available_at": "2018-07-02T16:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T17:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T18:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T19:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T20:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-02T21:00:00.000000Z", "subject_ids": [2841]},
            {"available_at": "2018-07-02T22:00:00.000000Z", "subject_ids": []},
            {
                "available_at": "2018-07-02T23:00:00.000000Z",
                "subject_ids": [2945, 672, 2956, 2932, 2981, 2953, 674, 2936, 654],
            },
            {"available_at": "2018-07-03T00:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-03T01:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-03T02:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-03T03:00:00.000000Z", "subject_ids": []},
            {
                "available_at": "2018-07-03T04:00:00.000000Z",
                "subject_ids": [
                    671,
                    853,
                    3709,
                    2959,
                    4849,
                    2970,
                    2960,
                    2966,
                    2967,
                    2952,
                    2946,
                    8663,
                    2962,
                    2961,
                    2973,
                    2938,
                    2935,
                    2940,
                    7461,
                    2969,
                    2958,
                    2937,
                    7736,
                    2957,
                    8801,
                    2974,
                    677,
                    2939,
                    675,
                    663,
                    668,
                    650,
                    664,
                    670,
                    660,
                    676,
                ],
            },
            {"available_at": "2018-07-03T05:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-03T06:00:00.000000Z", "subject_ids": []},
            {"available_at": "2018-07-03T07:00:00.000000Z", "subject_ids": []},
        ],
    },
}
REVIEWS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/reviews",
    "pages": {
        "per_page": 1000,
        "next_url": "https://api.wanikani.com/v2/reviews?page_after_id=168707639",
        "previous_url": None,
    },
    "total_count": 3,
    "data_updated_at": "2018-07-06T19:30:19.657822Z",
    "data": [
        {
            "id": 6418820,
            "object": "review",
            "url": "https://api.wanikani.com/v2/reviews/6418820",
            "data_updated_at": "2017-08-13T14:32:50.580980Z",
            "data": {
                "created_at": "2017-08-13T14:32:50.580980Z",
                "assignment_id": 69392456,
                "subject_id": 2514,
                "starting_srs_stage": 8,
                "ending_srs_stage": 9,
                "incorrect_meaning_answers": 0,
                "incorrect_reading_answers": 0,
            },
        },
        {
            "id": 6418839,
            "object": "review",
            "url": "https://api.wanikani.com/v2/reviews/6418839",
            "data_updated_at": "2017-08-13T14:32:52.693772Z",
            "data": {
                "created_at": "2017-08-13T14:32:52.693772Z",
                "assignment_id": 30950170,
                "subject_id": 69,
                "starting_srs_stage": 8,
                "ending_srs_stage": 9,
                "incorrect_meaning_answers": 0,
                "incorrect_reading_answers": 0,
            },
        },
        {
            "id": 6418872,
            "object": "review",
            "url": "https://api.wanikani.com/v2/reviews/6418872",
            "data_updated_at": "2017-08-13T14:32:56.587244Z",
            "data": {
                "created_at": "2017-08-13T14:32:56.587244Z",
                "assignment_id": 30950168,
                "subject_id": 60,
                "starting_srs_stage": 8,
                "ending_srs_stage": 9,
                "incorrect_meaning_answers": 0,
                "incorrect_reading_answers": 0,
            },
        },
    ],
}

LEVEL_PROGRESSIONS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/level_progressions",
    "pages": {"per_page": 500, "next_url": None, "previous_url": None},
    "total_count": 2,
    "data_updated_at": "2018-07-05T18:03:21.967992Z",
    "data": [
        {
            "id": 15446,
            "object": "level_progression",
            "url": "https://api.wanikani.com/v2/level_progressions/15446",
            "data_updated_at": "2018-07-05T15:04:04.222661Z",
            "data": {
                "created_at": "2017-09-28T01:24:11.715238Z",
                "level": 7,
                "unlocked_at": "2017-06-12T15:24:48.181971Z",
                "started_at": "2017-09-28T01:24:11.707880Z",
                "passed_at": "2018-07-05T15:04:04.210181Z",
                "completed_at": None,
                "abandoned_at": None,
            },
        },
        {
            "id": 365549,
            "object": "level_progression",
            "url": "https://api.wanikani.com/v2/level_progressions/365549",
            "data_updated_at": "2018-07-05T18:03:21.967992Z",
            "data": {
                "created_at": "2018-07-05T15:04:04.365184Z",
                "level": 8,
                "unlocked_at": "2018-07-05T15:04:04.338492Z",
                "started_at": "2018-07-05T18:03:21.957917Z",
                "passed_at": None,
                "completed_at": None,
                "abandoned_at": None,
            },
        },
    ],
}

RESETS_PAGE = {
    "object": "collection",
    "url": "https://api.wanikani.com/v2/resets",
    "pages": {"per_page": 500, "next_url": None, "previous_url": None},
    "total_count": 1,
    "data_updated_at": "2018-03-21T22:07:39.261116Z",
    "data": [
        {
            "id": 6529,
            "object": "reset",
            "url": "https://api.wanikani.com/v2/resets/6529",
            "data_updated_at": "2018-03-21T22:07:39.261116Z",
            "data": {
                "created_at": "2018-03-21T22:04:13.313903Z",
                "original_level": 13,
                "target_level": 1,
                "confirmed_at": "2018-03-21T22:05:44.454026Z",
            },
        }
    ],
}
